Enzymes methylation sensitivities
----------------------------------
File ``enzyme_infos.csv`` contains enzyme data from the REBASE database,
and file ``update_enzymes_list.py`` implements the web-scraping code used
to create or update the list. You can (re)run it with

```
python update_enzymes_list.py
```

The rebase website says:

No license is required for users to include REBASE in their projects, since we
do not have any software available for sharing at this time. Thus those seeking
to distribute REBASE files or utilize our data are welcome to do so, having
cited us as a bibliographical resource:

LATEST REVIEW: 	PDF file... 	PubMed 25378308
Roberts, R.J., Vincze, T., Posfai, J., Macelis, D.
REBASE-a database for DNA restriction and modification: enzymes, genes and genomes.
Nucleic Acids Res. 43: D298-D299 (2015).
doi: 10.1093/nar/gku1046
